@@ -3,8 +3,8 @@ Created on 21.07.2021
 
 @author: wf
 '''
-from smw.pagefixer import EntityFixer, PageFixerManager
-from openresearch.event import EventList, EventSeriesList
+from ormigrate.smw.pagefixer import EntityFixer, PageFixerManager
+from datasources.openresearch import OREventManager, OREventSeriesManager
 
 class ORFixer(EntityFixer):
     '''
@@ -17,6 +17,6 @@ class ORFixer(EntityFixer):
         '''
         super(ORFixer,self).__init__(pageFixerManager, debug)
         # workaround as long as we can't use MetaModel information directly from the wiki
-        self.propertyLookups["Event"]=EventList.getPropertyLookup()
-        self.propertyLookups["Event series"]=EventSeriesList.getPropertyLookup()
+        self.propertyLookups["Event"]=OREventManager.getPropertyLookup()
+        self.propertyLookups["Event series"]=OREventSeriesManager.getPropertyLookup()
         
\ No newline at end of file
